﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;

using System.IO;
using Microsoft.Office.Interop.Word;
using Microsoft.Win32;
using Word = Microsoft.Office.Interop.Word;
using System.Windows.Xps.Packaging;

/*
 * File Renaming Wizard copyright (c) 2014 Matthew Schlachter
 * See LICENSE.txt for distribution and modification restrictions
 * 
 * http://www.webmann.info/
 */
namespace Controls
{
    /// <summary>
    /// Interaction logic for DocBrowser.xaml;
    /// 
    /// Adapted from various unlicensed online forum responses,
    /// mainly on http://www.stackoverflow.com
    /// </summary>
    public partial class DocBrowser : UserControl
    {

        public DocBrowser()
        {
            InitializeComponent();
        }

        /// <summary>
        /// Load the document into the preview browser
        /// </summary>
        /// <param name="fileName">The filename (including the path)</param>
        public void LoadDocument(string fileName)
        {
            string wordDocument = fileName;
            if (string.IsNullOrEmpty(wordDocument) || !File.Exists(wordDocument))
            {
                //==[ If the filename is empty or the file doesn't exist, get out of here!
                throw new Exception();
            }
            else
            {
                try
                {
                    //==[ Convert the document to XPS and try loading it
                    string convertedXpsDoc = string.Concat(Path.GetTempPath(), "\\", Guid.NewGuid().ToString(), ".xps");
                    XpsDocument xpsDocument = ConvertWordToXps(wordDocument, convertedXpsDoc);
                    if (xpsDocument == null)
                    {
                        throw new Exception();
                        // return;
                    }
                    documentviewWord.Document = xpsDocument.GetFixedDocumentSequence();
                }
                catch
                {
                    throw new Exception();
                }
                documentviewWord.FitToWidth();
                documentviewWord.IsTabStop = false;
            }
        }

        /// <summary> 
        ///  Convert the word document to xps document
        /// </summary> 
        /// <param name="wordFilename">Word document Path</param> 
        /// <param name="xpsFilename">Xps document Path</param> 
        /// <returns></returns> 
        private XpsDocument ConvertWordToXps(string wordFilename, string xpsFilename)
        {
            // Create a WordApplication and host word document 
            Word.Application wordApp = new Microsoft.Office.Interop.Word.Application();
            try
            {
                wordApp.Documents.Open(wordFilename);

                // To Invisible the word document 
                wordApp.Application.Visible = false;


                // Minimize the opened word document 
                wordApp.WindowState = WdWindowState.wdWindowStateMinimize;


                Document doc = wordApp.ActiveDocument;


                doc.SaveAs(xpsFilename, WdSaveFormat.wdFormatXPS);


                XpsDocument xpsDocument = new XpsDocument(xpsFilename, FileAccess.Read);
                return xpsDocument;
            }
            catch (Exception ex)
            {
                throw ex;
            }
            finally
            {
                wordApp.Documents.Close();
                ((_Application)wordApp).Quit(WdSaveOptions.wdDoNotSaveChanges);
            }
        }

    }
}
